/**
 ********************************************************************************
 * @file    SPI_IO_nRF.h
 * @author  A. Guzman
 * @date    July 2, 2025
 * @brief
 ********************************************************************************
 */

#include <zephyr/kernel.h>
#include <zephyr/drivers/spi.h>
#include <zephyr/drivers/gpio.h>

#include <string.h>

#include "SPI_IO_nRF.h"

extern struct spi_dt_spec spi_dev;
extern struct gpio_dt_spec cs_gpio;

// void SPI_IO_CS_Low(void) {
//     gpio_pin_set_dt(&cs_gpio, 0);
// }

// void SPI_IO_CS_High(void) {
//     gpio_pin_set_dt(&cs_gpio, 1);
// }

void SPI_IO_Delay(uint32_t ms) {
    k_msleep(ms);
}

int SPI_IO_Transfer(const struct spi_dt_spec *spi,
                    const uint8_t *tx_buf,
                    uint8_t *rx_buf,
                    size_t len)
{
    struct spi_buf tx = {
        .buf = (void *)tx_buf,
        .len = len
    };
    struct spi_buf rx = {
        .buf = rx_buf,
        .len = len
    };

    struct spi_buf_set tx_set = {
        .buffers = &tx,
        .count = 1
    };
    struct spi_buf_set rx_set = {
        .buffers = &rx,
        .count = 1
    };

    return spi_transceive_dt(spi, &tx_set, &rx_set);
}
